pub struct Time {}
Holds the system clock source, active timer list, and kernel uptime counter.
TypeId
self
Returns the argument unchanged.
Calls U::from(self).
U::from(self)
That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.
[From]<T> for U